<?php

use CRM_Loginsecurity_ExtensionUtil as E;

class CRM_Loginsecurity_Utils_Check_InvalidLogins {

  function check(&$messages) {
    $userFramework = CRM_Core_Config::singleton()->userFramework;

    if ($userFramework == 'Drupal' || $userFramework == 'Drupal8') {
      // @todo We should use the CMS functions because this will break if the DBs are separate
      $count = CRM_Core_DAO::singleValueQuery('SELECT count(*)
        FROM watchdog
        WHERE type = "user"
          AND message LIKE "Login attempt failed%"
          AND timestamp > UNIX_TIMESTAMP(NOW()) - 3600');

      if ($count > 10) {
        $messages[] = new CRM_Utils_Check_Message(
          'loginsecurity_failedlogins',
          // @todo Fix the URL for the Drupal page using the Drupal function
          E::ts('%1 failed logins in the past hour. More information is available in the <a href="%2">Drupal watchdog</a>.', [1 => $count, 2 => '/admin/reports/dblog?type[]=user']),
          E::ts('Login Security - Failed Logins'),
          \Psr\Log\LogLevel::CRITICAL,
          'fa-check'
        );
      }
      else {
        $messages[] = new CRM_Utils_Check_Message(
          'loginsecurity_failedlogins',
          E::ts('%1 failed logins in the past hour.', [1 => $count]),
          E::ts('Login Security - Failed Logins'),
          \Psr\Log\LogLevel::INFO,
          'fa-check'
        );
      }
    }
    
  }

}
