<?php

require_once 'loginsecurity.civix.php';
// phpcs:disable
use CRM_Loginsecurity_ExtensionUtil as E;
// phpcs:enable

/**
 * Implements hook_civicrm_config().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_config/
 */
function loginsecurity_civicrm_config(&$config) {
  _loginsecurity_civix_civicrm_config($config);

  $cid = CRM_Loginsecurity_BAO_LoginSecurityDevice::logCurrentSession();

  if ($cid && empty(CRM_Utils_Request::retrieveValue('snippet', 'String'))) {
    Civi::resources()
      ->addVars('loginsecurity', ['contact_id' => $cid])
      ->addScriptFile('loginsecurity', 'node_modules/@fingerprintjs/fingerprintjs/dist/fp.min.js')
      ->addScriptFile('loginsecurity', 'loginsecurity.js');
  }
}

/**
 * Implements hook_civicrm_apiWrappers().
 */
function loginsecurity_civicrm_apiWrappers(&$wrappers, $apiRequest) {
  $wrappers[] = new CRM_Loginsecurity_APIWrappers();
}

/**
 * Implements hook_civicrm_xmlMenu().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_xmlMenu
 */
function loginsecurity_civicrm_xmlMenu(&$files) {
  _loginsecurity_civix_civicrm_xmlMenu($files);
}

/**
 * Implements hook_civicrm_install().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_install
 */
function loginsecurity_civicrm_install() {
  _loginsecurity_civix_civicrm_install();
}

/**
 * Implements hook_civicrm_postInstall().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_postInstall
 */
function loginsecurity_civicrm_postInstall() {
  _loginsecurity_civix_civicrm_postInstall();
}

/**
 * Implements hook_civicrm_uninstall().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_uninstall
 */
function loginsecurity_civicrm_uninstall() {
  _loginsecurity_civix_civicrm_uninstall();
}

/**
 * Implements hook_civicrm_enable().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_enable
 */
function loginsecurity_civicrm_enable() {
  _loginsecurity_civix_civicrm_enable();
}

/**
 * Implements hook_civicrm_disable().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_disable
 */
function loginsecurity_civicrm_disable() {
  _loginsecurity_civix_civicrm_disable();
}

/**
 * Implements hook_civicrm_upgrade().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_upgrade
 */
function loginsecurity_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
  return _loginsecurity_civix_civicrm_upgrade($op, $queue);
}

/**
 * Implements hook_civicrm_managed().
 *
 * Generate a list of entities to create/deactivate/delete when this module
 * is installed, disabled, uninstalled.
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_managed
 */
function loginsecurity_civicrm_managed(&$entities) {
  _loginsecurity_civix_civicrm_managed($entities);
}

/**
 * Implements hook_civicrm_angularModules().
 *
 * Generate a list of Angular modules.
 *
 * Note: This hook only runs in CiviCRM 4.5+. It may
 * use features only available in v4.6+.
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_angularModules
 */
function loginsecurity_civicrm_angularModules(&$angularModules) {
  _loginsecurity_civix_civicrm_angularModules($angularModules);
}

/**
 * Implements hook_civicrm_alterSettingsFolders().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_alterSettingsFolders
 */
function loginsecurity_civicrm_alterSettingsFolders(&$metaDataFolders = NULL) {
  _loginsecurity_civix_civicrm_alterSettingsFolders($metaDataFolders);
}

/**
 * Implements hook_civicrm_entityTypes().
 *
 * Declare entity types provided by this module.
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_entityTypes
 */
function loginsecurity_civicrm_entityTypes(&$entityTypes) {
  _loginsecurity_civix_civicrm_entityTypes($entityTypes);
}

/**
 * Implements hook_civicrm_themes().
 */
function loginsecurity_civicrm_themes(&$themes) {
  _loginsecurity_civix_civicrm_themes($themes);
}

/**
 * Implements hook_civicrm_navigationMenu().
 *
 * @link https://docs.civicrm.org/dev/en/latest/hooks/hook_civicrm_navigationMenu
 */
function loginsecurity_civicrm_navigationMenu(&$menu) {
  _loginsecurity_civix_insert_navigation_menu($menu, 'Administer/System Settings', [
    'label' => E::ts('Login Security'),
    'name' => 'loginsecurity_settings',
    'url' => 'civicrm/admin/setting/loginsecurity',
    'permission' => 'administer CiviCRM system',
    'operator' => 'OR',
    'separator' => 0,
  ]);
  _loginsecurity_civix_navigationMenu($menu);
}

/**
 * Implements hook_civicrm_tabset().
 */
function loginsecurity_civicrm_tabset($tabsetName, &$tabs, $context) {
  if ($tabsetName != 'civicrm/contact/view') {
    return;
  }

  $contact_id = $context['contact_id'];

  // Users may view their own history, otherwise must be a system admin
  if (!(CRM_Core_Permission::check('administer CiviCRM system') || CRM_Core_Session::getLoggedInContactID() == $contact_id)) {
    return;
  }

  // Check if the contact record is linked to a CMS user
  $uf_id = CRM_Core_DAO::singleValueQuery('SELECT uf_id from civicrm_uf_match WHERE contact_id = %1', [
    1 => [$contact_id, 'Positive'],
  ]);

  if (!$uf_id) {
    return;
  }

  $url = CRM_Utils_System::url('civicrm/contact/loginhistory', "reset=1&snippet=1&force=1&cid=$contact_id");

  $tabs[] = [
    'id' => 'loginsecurityTab',
    'url'   => $url,
    'title' => E::ts('Access History'),
    'count' => '',
    'icon' => 'crm-i fa-lock',
    'weight' => 900,
  ];
}

/**
 * Implements hook_civicrm_check().
 */
function loginsecurity_civicrm_check(&$messages) {
  $checks = [
    'InvalidLogins',
  ];

  foreach ($checks as $c) {
    $t = 'CRM_Loginsecurity_Utils_Check_' . $c;
    if (class_exists($t)) {
      $class = new $t();
      $class->check($messages);
    }
  }
}
